# javaver nil: build for 1.5.0 and 1.6.0
# javaver something else: build only for that

# Java >= 1.7.0 stuff can't coexist in jar with older versions
%global javaver 1.8.0
%global headless -headless

%global __provides_exclude_from ^%{_libdir}/%{name}/.*\.so$
%define _disable_ld_no_undefined 1

Name:           javasqlite
Version:        20140624
Release:        %mkrel 8
Summary:        SQLite Java Wrapper/JDBC Driver
Group:          Development/Java
License:        BSD
URL:            http://www.ch-werner.de/javasqlite/
Source0:        http://www.ch-werner.de/javasqlite/%{name}-%{version}.tar.gz
# Fedora specific, no need to send upstream.
Patch0:         %{name}-20090430-jnipath.patch
# Sent upstream 2014-06-28
Patch1:         0001-Make-buildable-with-Java-1.8.patch

# >= 3.4 for zeroblob stuff in %%check's test3
BuildRequires:  sqlite-devel >= 3.4
BuildRequires:  sqlite3-devel
%if 0%{?javaver:1}
BuildRequires:  java-%{javaver}-devel
BuildRequires:  java-%{javaver}-javadoc
Requires:       jre-%{javaver}%{?headless}
%else
BuildRequires:  java-1.6.0-devel
BuildRequires:  java-1.6.0-javadoc
BuildRequires:  java-1.5.0-devel
Requires:       jre%{?headless} >= 1.5.0
%endif

%description
javasqlite is a Java wrapper including a basic JDBC driver for the
SQLite database engine. It is designed using JNI to interface to the
SQLite API.

%package        javadoc
Summary:        API documentation for %{name}
Group:          Documentation
BuildArch:      noarch
Requires:       java-javadoc

%description    javadoc
API documentation for %{name}.


%prep
%setup -q
sed -e 's|@JNIPATH@|%{_libdir}/%{name}|' %{PATCH0} | patch -p1 --fuzz=0
%patch1 -p1 -b .java18
for f in configure{,.in}; do touch -r $f.java18 $f; done
sed -i -e 's/\r//g' doc/ajhowto.txt
f=ChangeLog ; iconv -f iso-8859-1 -t utf-8 $f > $f.utf8 ; mv $f.utf8 $f
rm doc/stylesheet.css # overrides javadoc's defaults

# Fixed javadoc build on JDK 8 (disabling the super-strict doclint checks)
sed -i 's|\$(JAVADOC) |\$(JAVADOC) -Xdoclint:none |' Makefile.in

%build
origpath="$PATH"
# Note that --enable-load-extension has security concerns, see configure --help
common_flags="
    --with-jardir=%{_libdir}/%{name}
    --libdir=%{_libdir}/%{name}
"

%if 0%{?javaver:1}

export PATH="%{_jvmdir}/java-%{javaver}/bin:$origpath" # bug 460761
%configure $common_flags --with-jdk=%{_jvmdir}/java-%{javaver}
make sqlite.jar # Java build not parallel clean
make %{?_smp_mflags}

%else

# We build both JDBC 3 and 4 drivers here so the resulting jar includes both,
# and in a way that the classfiles are usable with both Java 1.5 and 1.6.
# The idea is to first build the JDBC 3 driver and common files with Java 1.5,
# then JDBC 4 and remaining files with Java 1.6, the desired result being that
# the Java 1.6 build will not recompile the common class files that were
# previously built with 1.5.

# Pass #1: JDBC 3 driver and common files with 1.5.0
export PATH="%{_jvmdir}/java-1.5.0/bin:$origpath" # bug 460761
%configure $common_flags --with-jdk=%{_jvmdir}/java-1.5.0
make sqlite.jar JAVAC_FLAGS="-source 5" # Java build not parallel clean

# Pass #2: JDBC 4 driver and the rest with 1.6.0
export PATH="%{_jvmdir}/java-1.6.0/bin:$origpath" # bug 460761 (to be sure)
%configure $common_flags --with-jdk=%{_jvmdir}/java-1.6.0
make # Java build not parallel clean

# Add JDBC 3 classes
jar uf sqlite.jar SQLite/JDBC2y/*.class

%endif

make javadoc JAVADOCLINK=%{_javadocdir}/java


%install
make install DESTDIR=$RPM_BUILD_ROOT
rm -f $RPM_BUILD_ROOT%{_libdir}/%{name}/libsqlite_jni.la
install -dm 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}
cp -pR doc/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}


%check
origpath="$PATH"
for javaver in %{?javaver} %{!?javaver:1.5.0 1.6.0} ; do
    jdir=%{_jvmdir}/java-$javaver/bin
    export PATH="$jdir:$origpath" # bug 460761
    # test2 is for SQLite 2.x, which we don't support
    make JAVA_RUN="$jdir/java" JAVAC="$jdir/javac" test test3 testg
done


%files
%doc ChangeLog license.terms
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/sqlite.jar
%{_libdir}/%{name}/libsqlite_jni.so

%files javadoc
%doc license.terms
%{_javadocdir}/%{name}



%changelog
* Sat Dec 05 2020 luigiwalser <luigiwalser> 20140624-8.mga8
+ Revision: 1653214
- try not calling autoreconf
- remove previous build fix which breaks build

* Thu Feb 13 2020 umeabot <umeabot> 20140624-7.mga8
+ Revision: 1513676
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 20140624-6.mga7
+ Revision: 1298359
- Mageia 7 Mass Rebuild

* Thu Aug 16 2018 wally <wally> 20140624-5.mga7
+ Revision: 1252034
- fix build on aarch64

* Sat Mar 12 2016 daviddavid <daviddavid> 20140624-4.mga6
+ Revision: 989554
- fix javadoc build on JDK 8 (disabling the super-strict doclint checks)
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 20140624-3.mga5
+ Revision: 741507
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 20140624-2.mga5
+ Revision: 680656
- Mageia 5 Mass Rebuild

* Tue Aug 05 2014 luigiwalser <luigiwalser> 20140624-1.mga5
+ Revision: 660049
- try to fix patch so it will work with autoreconf
- update to 20140624
- sync with fedora to build with java 8
- switch to java-1.8.0-openjdk

* Mon Jan 06 2014 dmorgan <dmorgan> 20130214-3.mga4
+ Revision: 564977
- Fix java buildrequires
- New version
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 20120209-2.mga3
+ Revision: 354846
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 15 2012 fwang <fwang> 20120209-1.mga3
+ Revision: 318169
- fix build
- new version 20120209 (build with sqlite3)

* Fri Feb 18 2011 wally <wally> 20110106-1.mga1
+ Revision: 53538
- new version 20110106
- sync patches with Fedora
- tag javadoc subpackage as noarch
- clean .spec
- imported package javasqlite


* Wed Feb 18 2009 Jérôme Soyer <saispo@mandriva.org> 20081006-0.1.0mdv2009.1
+ Revision: 342343
- Disable test
- New upstream release

* Tue Jun 17 2008 Alexander Kurtakov <akurtakov@mandriva.org> 20080420-0.1.1mdv2009.0
+ Revision: 223772
- new version 20080420, removed not needed patches

* Wed May 14 2008 David Walluck <walluck@mandriva.org> 20080401-0.2.1mdv2009.0
+ Revision: 206934
- import javasqlite


* Thu Apr  3 2008 Ville Skyttä <ville.skytta at iki.fi> - 20080401-2
- First Fedora build.

* Wed Apr  2 2008 Ville Skyttä <ville.skytta at iki.fi> - 20080401-1
- Update to 20080401.
- Patch to install *.so as an unversioned module.
- Patch to fix parallel make (#439941, Colin Walters).
- Build with "-source 5" instead of "-source 5.0" (#439941, Colin Walters).
- Use %%{_jvmdir} instead of %%{_prefix}/lib/jvm.

* Thu Mar 20 2008 Ville Skyttä <ville.skytta at iki.fi> - 20080315-1
- 20080315; classpath, lib64, and getboolean patches applied upstream.
- Install to %%{_libdir}/%%{name} per current Fedora packaging guidelines.
- Patch to appease recent libtool.
- Patch to honor $RPM_OPT_FLAGS.

* Sat Nov 10 2007 Ville Skyttä <ville.skytta at iki.fi> - 20070915-0.2
- Build with -source 5.0.
- More classpath fixes.

* Tue Sep 18 2007 Ville Skyttä <ville.skytta at iki.fi> - 20070915-0.1
- 20070915.
- Disable parallel build, doesn't work.
- Patch to fix build and test suite classpath.
- Patch to add support for ResultSet.getBoolean().

* Fri Sep 14 2007 Ville Skyttä <ville.skytta at iki.fi> - 20070914-0.1
- First build.
